import { Auth, CredentialManager } from '@genesislcap/foundation-comms';
/**
 * Events dispatched by the navigation control buttons
 * @public
 */
export type NavEventDetailMap = {
    'luminance-icon-clicked': void;
    'misc-icon-clicked': void;
    'notification-icon-clicked': void;
};
declare const Navigation_base: abstract new (...args: any[]) => {
    $emit<K extends "luminance-icon-clicked" | "misc-icon-clicked" | "notification-icon-clicked">(...args: NavEventDetailMap[K] extends void ? [type: K, options?: import("@genesislcap/foundation-events").EmitOptions] : [type: K, detail: NavEventDetailMap[K], options?: import("@genesislcap/foundation-events").EmitOptions]): import("@genesislcap/foundation-events").EmitReturn;
    readonly $fastController: import("@microsoft/fast-element").Controller;
    connectedCallback(): void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
};
/**
 * Navigation micro-frontend includes navigation bar and flyout menu
 *
 * @remarks
 *
 * `foundation-header` micro-frontend can be added to the project to include a navigation bar
 * and flyout menu. There are multiple ways that the behaviour of the component can be configured
 * - the icon shown on the navigation bar and flyout menu (this shows the Genesis logo by default).
 * - navigation links at the left-hand side of the navigation bar.
 * - the control buttons on the right-hand side of the navigation bar can be shown or hidden, and their behaviour controlled via event listeners
 * - The contents of the flyout menu.
 *
 * @param logo-src - Option attribute which sets the source of the image in the navigation bar and flyout menu. The Genesis logo will be shown if this attribute is not provided.
 * @param show-luminance-toggle-button - Boolean attribute which controls whether the navigation bar will display the luminance toggle icon.
 * @param show-misc-toggle-button - Boolean attribute which controls whether the navigation bar will display the miscellaneous behaviour icon.
 * @param show-misc-toggle-button - Boolean attribute which controls whether the navigation bar will display the show notification icon.
 *
 * @public
 */
export declare class Navigation extends Navigation_base {
    auth: Auth;
    credentialManager: CredentialManager;
    ready: boolean;
    /**
     * Username of the logged in user
     */
    userName: string;
    sideNavOpen: boolean;
    connectedCallback(): Promise<void>;
    /**
     * Optional attribute which controls the icon to show on the navigation bar and flyout
     * Control via `logo-src`
     *
     * @remarks
     *
     * If this attribute is not set then the Genesis logo is shown instead
     */
    logoSrc: any;
    /**
     * Boolean attribute which controls whether to show the luminance (moon) icon on the navigation bar
     * Control via`show-luminance-toggle-button`
     *
     * @remarks
     *
     * If the user clicks the icon when shown then this class will emit the 'luminance-icon-clicked' event
     */
    showLuminanceToggleButton: boolean;
    /**
     * Boolean attribute which controls whether to show the miscellaneous (menu) icon on the navigation bar
     * Control via `show-luminance-toggle-button`
     *
     * @remarks
     *
     * If the user clicks the icon when shown then this class will emit the 'misc-icon-clicked' event
     */
    showMiscToggleButton: boolean;
    /**
     * Boolean attribute which controls whether to show the notification (bell) icon on the navigation bar
     * Control via `show-notification-button`
     *
     * @remarks
     *
     * If the user clicks the icon when shown then this class will emit the 'notification-icon-clicked' event
     */
    showNotificationsButton: boolean;
    /**
     * Boolean attribute which controls whether to show the connection indicator on the navigation bar
     * Control via `show-connection-indicator`
     *
     */
    showConnectionIndicator: boolean;
    /**
     * Boolean attribute which controls whether to include the sideNav component
     * Control via`hide-side-bar`
     *
     */
    hideSideBar: boolean;
    /**
     * If present the defined route buttons will be rendered in the header 'routes' slot
     */
    routeButtons: Array<{
        index: number;
        path: string;
        title: string;
        icon: string;
        variant: string;
    }>;
    /**
     * Load remote components
     *
     * @remarks
     *
     * With regards to module federation
     *
     * @internal
     */
    loadRemotes(): Promise<void>;
    selectTemplate(): import("@microsoft/fast-element").ViewTemplate<Navigation, any>;
    /**
     * Logs the user out of their session
     *
     * @remarks
     *
     * Activated when the user clicks on the logout button on the right hand side of the navigation bar. Requires
     * the usage of the auth functionality from {@link @genesislcap/foundation-comms#Auth}.
     *
     * @public
     */
    logout(): Promise<void>;
    /**
     * Changes the route of the current page
     *
     * @remarks
     *
     * Requires setup of the Router and usage of the FAST Router
     *
     * @param path - string represeting the new route to move to
     *
     * @public
     */
    navigateTo(path: string): void;
    /**
     * Opens the flyout menu on the left hand side
     *
     * @remarks
     *
     * Activated when the user clicks on the menu button on the navigation
     * bar left hand side
     *
     * @internal
     */
    toggleNavVisibility(): void;
    /**
     * Emits the event corresponding to the luminance icon being clicked
     *
     * @remarks
     *
     * Activated when the user clicks on the moon icon on the navigation
     * bar right hand side
     *
     * @internal
     */
    luminanceIconEvent(): void;
    /**
     * Emits the event corresponding to the miscellaneous icon being clicked
     *
     * @remarks
     *
     * Activated when the user clicks on the menu icon on the navigation
     * bar right hand side
     *
     * @internal
     */
    miscIconEvent(): void;
    /**
     * Emits the event corresponding to the notification icon being clicked
     *
     * @remarks
     *
     * Activated when the user clicks on the bell icon on the navigation
     * bar right hand side
     *
     * @internal
     */
    notificationIconEvent(): void;
}
export {};
//# sourceMappingURL=main.d.ts.map